@@ -11,7 +11,7 @@ exports.localization.appName ={
   "de": "GeoGebra Classic",
   "el": "Εφαρμογές Μαθηματικών",
   "es": "GeoGebra Clásico",
-  "fa": "GeoGebra Classic",
+  "fa": "جئوجبرا کلاسیک",
   "fi": "GeoGebra Classic",
   "fr": "GeoGebra Classique",
   "hr": "Klasična GeoGebra",
