@@ -441,11 +441,21 @@ function onReady() {
                 associateExeForFile('GeoGebra6FileAssociation', 'GeoGebra file',
                     process.execPath,
                     appFolder + '\\Update.exe --processStart=GeoGebra.exe --process-start-args="%0"', '.ggb');
-                    // C:\Users\Kovács Zoltán\AppData\Local\GeoGebra_6\Update.exe --processStart=GeoGebra.exe --process-start-args="%0"
+                    // C:\Users\...\AppData\Local\GeoGebra_6\Update.exe --processStart=GeoGebra.exe --process-start-args="%0"
                 printDebug("File association");
 
             } else if (val.match(/^--squirrel-update/)) {
                 updateShortcuts();
+                printDebug("Icon update");
+                // THIS PIECE OF CODE IS UNTESTED. MAYBE WE NEED TO PUT IT TO A DIFFERENT PLACE...
+                // File association
+                var appFolder = process.execPath.replace(/\\[^\\]*\\[^\\]*$/, "");
+                associateExeForFile('GeoGebra6FileAssociation', 'GeoGebra file',
+                    process.execPath,
+                    appFolder + '\\Update.exe --processStart=GeoGebra.exe --process-start-args="%0"', '.ggb');
+                    // C:\Users\...\AppData\Local\GeoGebra_6\Update.exe --processStart=GeoGebra.exe --process-start-args="%0"
+                printDebug("File association update");
+                // END OF UNTESTED CODE
 
             } else {
                 // --squirrel-obsolete, ...
@@ -620,7 +630,14 @@ function parseCommandLineOptions() {
                 var absfile = path.relative(appAbsPath, val);
                 printInfo("Attempt to load file " + val);
                 try {
-                    ggbfile = fs.readFileSync(path.join(__dirname, absfile));
+                    try {
+                        // attempt to load it via a relative path
+                        ggbfile = fs.readFileSync(path.join(__dirname, absfile));
+                        }
+                    catch (e) {
+                        // attempt to load it via an absolute path
+                        ggbfile = fs.readFileSync(absfile);
+                        }
                     ggbbase64 = Buffer.from(ggbfile).toString('base64');
                 } catch (e) {
                     printError("Cannot open file", e);
